==> qtjambi-multimedia-debuginfo-macos-6.5.3.jar: sources/QtJambiMultimedia/QVideoFrame_PaintOptions_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtMultimedia/qvideoframe.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiMultimedia/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QVideoFrame_PaintOptions(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QVideoFrame::PaintOptions")
    QVideoFrame::PaintOptions *_ptr = reinterpret_cast<QVideoFrame::PaintOptions *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new 
void __qt_construct_QVideoFrame_PaintOptions_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QVideoFrame::PaintOptions *__qt_this = new(__qtjambi_ptr) QVideoFrame::PaintOptions();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QVideoFrame::PaintOptions
void __qt_destruct_QVideoFrame_PaintOptions(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QVideoFrame::PaintOptions")
    reinterpret_cast<QVideoFrame::PaintOptions*>(ptr)->~PaintOptions();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QVideoFrame::PaintOptions::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QVideoFrame_00024PaintOptions_initialize_1native__Lio_qt_multimedia_QVideoFrame_00024PaintOptions_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QVideoFrame::PaintOptions::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QVideoFrame_PaintOptions_0, sizeof(QVideoFrame::PaintOptions), typeid(QVideoFrame::PaintOptions), false, &deleter_QVideoFrame_PaintOptions, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QVideoFrame::PaintOptions::operator==(QVideoFrame::PaintOptions,QVideoFrame::PaintOptions)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QVideoFrame_00024PaintOptions_operator_1equal_1native_1cref_1QVideoFrame_1PaintOptions__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID value21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QVideoFrame::PaintOptions *__qt_this = QtJambiAPI::objectFromNativeId<QVideoFrame::PaintOptions>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QVideoFrame::PaintOptions::operator==(QVideoFrame::PaintOptions,QVideoFrame::PaintOptions)", __qt_this)
        const QVideoFrame::PaintOptions& __qt_value21 = QtJambiAPI::valueReferenceFromNativeId<QVideoFrame::PaintOptions>(value21);
        __java_return_value = (*__qt_this) == __qt_value21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QVideoFrame_00024PaintOptions_setAspectRatioMode_1native_1cref_1Qt_1AspectRatioMode__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint aspectRatioMode0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QVideoFrame::PaintOptions *__qt_this = QtJambiAPI::objectFromNativeId<QVideoFrame::PaintOptions>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        Qt::AspectRatioMode __qt_aspectRatioMode0 = qtjambi_cast<Qt::AspectRatioMode>(__jni_env, aspectRatioMode0);
        __qt_this->aspectRatioMode = Qt::AspectRatioMode(__qt_aspectRatioMode0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QVideoFrame_00024PaintOptions_aspectRatioMode_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QVideoFrame::PaintOptions *__qt_this = QtJambiAPI::objectFromNativeId<QVideoFrame::PaintOptions>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const Qt::AspectRatioMode&  __qt_value = __qt_this->aspectRatioMode;
        __java_return_value = __qt_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QVideoFrame_00024PaintOptions_setBackgroundColor_1native_1cref_1QColor__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID backgroundColor0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QVideoFrame::PaintOptions *__qt_this = QtJambiAPI::objectFromNativeId<QVideoFrame::PaintOptions>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QColor& __qt_backgroundColor0 = QtJambiAPI::valueReferenceFromNativeId<QColor>(backgroundColor0);
        __qt_this->backgroundColor = __qt_backgroundColor0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QVideoFrame_00024PaintOptions_backgroundColor_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QVideoFrame::PaintOptions *__qt_this = QtJambiAPI::objectFromNativeId<QVideoFrame::PaintOptions>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QColor&  __qt_value = __qt_this->backgroundColor;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QVideoFrame_00024PaintOptions_setPaintFlags_1native_1cref_1QVideoFrame_1PaintOptions_1PaintFlags__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint paintFlags0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QVideoFrame::PaintOptions *__qt_this = QtJambiAPI::objectFromNativeId<QVideoFrame::PaintOptions>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QVideoFrame::PaintOptions::PaintFlags __qt_paintFlags0 = qtjambi_cast<QVideoFrame::PaintOptions::PaintFlags>(__jni_env, paintFlags0);
        __qt_this->paintFlags = QVideoFrame::PaintOptions::PaintFlags(__qt_paintFlags0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QVideoFrame_00024PaintOptions_paintFlags_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QVideoFrame::PaintOptions *__qt_this = QtJambiAPI::objectFromNativeId<QVideoFrame::PaintOptions>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QVideoFrame::PaintOptions::PaintFlags&  __qt_value = __qt_this->paintFlags;
        __java_return_value = __qt_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QVideoFrame_00024PaintOptions_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QVideoFrame::PaintOptions *__qt_this = QtJambiAPI::objectFromNativeId<QVideoFrame::PaintOptions>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QVideoFrame_00024PaintOptions_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QVideoFrame::PaintOptions *__qt_this = QtJambiAPI::objectFromNativeId<QVideoFrame::PaintOptions>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QVideoFrame_PaintOptions(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QVideoFrame::PaintOptions>("QVideoFrame::PaintOptions", "io/qt/multimedia/QVideoFrame$PaintOptions");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QVideoFrame_PaintOptions, {
        ConstructorInfo(&__qt_construct_QVideoFrame_PaintOptions_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QVideoFrame_PaintOptions);
    registerMetaType<QVideoFrame::PaintOptions>("QVideoFrame::PaintOptions");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QVideoFrame::PaintOptions::PaintFlag>("QVideoFrame::PaintOptions::PaintFlag", "io/qt/multimedia/QVideoFrame$PaintOptions$PaintFlag", "QVideoFrame::PaintOptions::PaintFlags", "QFlags<QVideoFrame::PaintOptions::PaintFlag>", "io/qt/multimedia/QVideoFrame$PaintOptions$PaintFlags");
// END: enums and flags
}

==> qtjambi-multimedia-debuginfo-macos-6.5.4.jar: sources/QtJambiMultimedia/QVideoFrame_PaintOptions_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtMultimedia/qvideoframe.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiMultimedia/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QVideoFrame_PaintOptions(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QVideoFrame::PaintOptions")
    QVideoFrame::PaintOptions *_ptr = reinterpret_cast<QVideoFrame::PaintOptions *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new 
void __qt_construct_QVideoFrame_PaintOptions_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QVideoFrame::PaintOptions *__qt_this = new(__qtjambi_ptr) QVideoFrame::PaintOptions();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QVideoFrame::PaintOptions
void __qt_destruct_QVideoFrame_PaintOptions(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QVideoFrame::PaintOptions")
    reinterpret_cast<QVideoFrame::PaintOptions*>(ptr)->~PaintOptions();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QVideoFrame::PaintOptions::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QVideoFrame_00024PaintOptions_initialize_1native__Lio_qt_multimedia_QVideoFrame_00024PaintOptions_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QVideoFrame::PaintOptions::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QVideoFrame_PaintOptions_0, sizeof(QVideoFrame::PaintOptions), typeid(QVideoFrame::PaintOptions), false, &deleter_QVideoFrame_PaintOptions, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QVideoFrame::PaintOptions::operator==(QVideoFrame::PaintOptions,QVideoFrame::PaintOptions)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QVideoFrame_00024PaintOptions_equals_1native_1cref_1QVideoFrame_1PaintOptions__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID value21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QVideoFrame::PaintOptions *__qt_this = QtJambiAPI::objectFromNativeId<QVideoFrame::PaintOptions>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QVideoFrame::PaintOptions::operator==(QVideoFrame::PaintOptions,QVideoFrame::PaintOptions)", __qt_this)
        const QVideoFrame::PaintOptions& __qt_value21 = QtJambiAPI::valueReferenceFromNativeId<QVideoFrame::PaintOptions>(value21);
        __java_return_value = (*__qt_this) == __qt_value21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QVideoFrame_00024PaintOptions_setAspectRatioMode_1native_1cref_1Qt_1AspectRatioMode__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint aspectRatioMode0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QVideoFrame::PaintOptions *__qt_this = QtJambiAPI::objectFromNativeId<QVideoFrame::PaintOptions>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        Qt::AspectRatioMode __qt_aspectRatioMode0 = qtjambi_cast<Qt::AspectRatioMode>(__jni_env, aspectRatioMode0);
        __qt_this->aspectRatioMode = Qt::AspectRatioMode(__qt_aspectRatioMode0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QVideoFrame_00024PaintOptions_aspectRatioMode_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QVideoFrame::PaintOptions *__qt_this = QtJambiAPI::objectFromNativeId<QVideoFrame::PaintOptions>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const Qt::AspectRatioMode&  __qt_value = __qt_this->aspectRatioMode;
        __java_return_value = __qt_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QVideoFrame_00024PaintOptions_setBackgroundColor_1native_1cref_1QColor__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID backgroundColor0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QVideoFrame::PaintOptions *__qt_this = QtJambiAPI::objectFromNativeId<QVideoFrame::PaintOptions>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QColor& __qt_backgroundColor0 = QtJambiAPI::valueReferenceFromNativeId<QColor>(backgroundColor0);
        __qt_this->backgroundColor = __qt_backgroundColor0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QVideoFrame_00024PaintOptions_backgroundColor_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QVideoFrame::PaintOptions *__qt_this = QtJambiAPI::objectFromNativeId<QVideoFrame::PaintOptions>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QColor&  __qt_value = __qt_this->backgroundColor;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QVideoFrame_00024PaintOptions_setPaintFlags_1native_1cref_1QVideoFrame_1PaintOptions_1PaintFlags__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint paintFlags0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QVideoFrame::PaintOptions *__qt_this = QtJambiAPI::objectFromNativeId<QVideoFrame::PaintOptions>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QVideoFrame::PaintOptions::PaintFlags __qt_paintFlags0 = qtjambi_cast<QVideoFrame::PaintOptions::PaintFlags>(__jni_env, paintFlags0);
        __qt_this->paintFlags = QVideoFrame::PaintOptions::PaintFlags(__qt_paintFlags0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QVideoFrame_00024PaintOptions_paintFlags_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QVideoFrame::PaintOptions *__qt_this = QtJambiAPI::objectFromNativeId<QVideoFrame::PaintOptions>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QVideoFrame::PaintOptions::PaintFlags&  __qt_value = __qt_this->paintFlags;
        __java_return_value = __qt_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QVideoFrame_00024PaintOptions_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QVideoFrame::PaintOptions *__qt_this = QtJambiAPI::objectFromNativeId<QVideoFrame::PaintOptions>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QVideoFrame_00024PaintOptions_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QVideoFrame::PaintOptions *__qt_this = QtJambiAPI::objectFromNativeId<QVideoFrame::PaintOptions>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QVideoFrame_PaintOptions(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QVideoFrame::PaintOptions>("QVideoFrame::PaintOptions", "io/qt/multimedia/QVideoFrame$PaintOptions");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QVideoFrame_PaintOptions, {
        ConstructorInfo(&__qt_construct_QVideoFrame_PaintOptions_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QVideoFrame_PaintOptions);
    registerMetaType<QVideoFrame::PaintOptions>("QVideoFrame::PaintOptions");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QVideoFrame::PaintOptions::PaintFlag>("QVideoFrame::PaintOptions::PaintFlag", "io/qt/multimedia/QVideoFrame$PaintOptions$PaintFlag", "QVideoFrame::PaintOptions::PaintFlags", "QFlags<QVideoFrame::PaintOptions::PaintFlag>", "io/qt/multimedia/QVideoFrame$PaintOptions$PaintFlags");
// END: enums and flags
}
